Changelog
=========

0.3.2
-----
#. Django 1.10 tests pass. Handle Django 1.11 widget refactor gracefully.

0.3.1
-----
#. Add a setting allowing as_p and as_table to be overridden globally.

0.3
---
#. Add a span tag hook for choice inputs. This allows CSS selectors to target the text inside the label tag.

0.2
---
#. Optional BEM classes.
#. Standardize as_div.

0.1.1
-----
#. Allow apps to specify custom renderers.

0.1
---
#. First release.

